#
# spec file for package picard
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           picard
Version:        2.1.3
Release:        1.1
Summary:        The Next Generation MusicBrainz Tagger
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://picard.musicbrainz.org
Source0:        https://codeload.github.com/metabrainz/picard/tar.gz/release-%{version}#/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libofa-devel
BuildRequires:  python3-devel
BuildRequires:  python3-mutagen
BuildRequires:  python3-qt5
BuildRequires:  python3-setuptools
BuildRequires:  python3-sip
BuildRequires:  update-desktop-files
Requires:       python3-mutagen
Requires:       python3-qt5
Recommends:     chromaprint-fpcalc
Recommends:     python3-discid

%description
MusicBrainz Picard is a MusicBrainz tag editor written in Python.
Picard Tagger focuses on album-oriented tagging as opposed to
track-based tagging.

%lang_package

%prep
%setup -q -n %{name}-release-%{version}

%build
export LANG=en_US.UTF-8
python3 setup.py config
python3 setup.py build

%install
export LANG=en_US.UTF-8
python3 setup.py install --skip-build --prefix=%{_prefix} --root=%{buildroot}

%suse_update_desktop_file -G "Music Tagger" -N "picard" org.musicbrainz.Picard

rm -rfv %{buildroot}%{_datadir}/locale/sco

%find_lang %{name} %{name}.lang
%find_lang %{name}-countries %{name}.lang
%find_lang %{name}-attributes %{name}.lang

%if 0%{?suse_version} < 1500
%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun
%endif

%files
%doc AUTHORS.txt NEWS.txt
%license COPYING.txt
%{_bindir}/picard
%{_datadir}/applications/org.musicbrainz.Picard.desktop
%{python3_sitearch}/picard*
%{_datadir}/icons/hicolor/*/apps/org.musicbrainz.Picard.png
%{_datadir}/icons/hicolor/*/apps/org.musicbrainz.Picard.svg
%{_datadir}/metainfo/org.musicbrainz.Picard.appdata.xml

%files lang -f %{name}.lang

%changelog
* Tue Mar  5 2019 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 2.1.3:
  * Bug-fix
  * [PICARD-323] – Only the discid of the first disc in a release is written to tags
  * [PICARD-455] – Picard setting cover art height, width and depth to 0 for FLAC files –> breaks libFLAC
  * [PICARD-729] – Tracks get stuck at “[loading track information]” on Bad Gateway errors
  * [PICARD-938] – Need two left-arrow key presses to go from track with file to album
  * [PICARD-1178] – Images tagged with extra types that the user has chosen to ignore should not be shown as ‘modified’
  * [PICARD-1288] – Folskonomy tags / genre fallback on album artists tags not working
  * [PICARD-1422] – Windows: Uninstall 32 bit Picard before upgrade
  * [PICARD-1447] – When releasing a new version, appdata should also be updated
  * [PICARD-1460] – Windows installer does not detect running instance
  * [PICARD-1461] – Crash when running with Spanish language
  * [PICARD-1463] – Picard crashes on startup on Windows
  * [PICARD-1469] – Force close when adding songs to larger albums
  * [PICARD-1471] – Artist searches do not show begin and end area
  * [PICARD-1473] – AcoustId lookup fails if fingerprint already in tags
  * [PICARD-1474] – Windows installer shows outdated version string in file properties
  * [PICARD-1475] – Cover art sources do not support HTTPS
  * [PICARD-1476] – Filled up thread pool prevents metadata box updates
  * [PICARD-1478] – Changing MB server requires a restart
  * [PICARD-1480] – Search line input clear button icon is too small
  * Task
  * [PICARD-1459] – Remove OptionsPage.info method
  * [PICARD-1472] – macOS code signing on Travis CI fails for xcode7.3 image
  * Improvement
  * [PICARD-1242] – Consider the number of AcoustID sources for linked recordings
  * [PICARD-1457] – “Check for Update” should be in the Picard menu
  * [PICARD-1458] – “Check for Update” should have an ellipsis at the end
  * [PICARD-1470] – Make warning about Qt locale loading less prominent
* Wed Jan 30 2019 mvetter@suse.com
- Update to 2.1.2:
  * Bug-fix
  * [PICARD-1451] - Redirects of authenticated requests fail with 401 error
  * [PICARD-1454] - Crashes when adding action to toolbar in options
  * Task
  * [PICARD-1452] - Appveyor auto-deploy not working
  * Improvement
  * [PICARD-1450] - Fix language label for zh_CN and zh_TW
* Sat Dec 22 2018 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 2.1.0:
  * support for MusicBrainz genres
  * new convenient script functions: $title and $delete
  * new command line option (-P, --no-plugins) allowing to skip plugin loading, which may help when a plugin is crashing Picard at start and to identify if an issue is due to a plugin or the main program
  * improve tags support, better compatibility with other applications, wider range of audio files supported
  * better stability and performance
  * full changelog available at https://blog.metabrainz.org/2018/12/21/picard-2-1-release/
- Picard has been refactored to org.musicbrainz.Picard
- Add appdata.xml file
* Fri Sep  7 2018 mvetter@suse.com
- Update to version 2.0.4:
  * Bug-fix
  * [PICARD-803] - tagging "8½ Minutes" with "replace with non-ascii characters" results in a directory being created
  * [PICARD-1216] - Does not display version information
  * [PICARD-1267] - 2.0.0dev6 crash in debug mode on Windows April Update (1803)
  * [PICARD-1281] - Picard has wrong version string
  * [PICARD-1294] - Crashes every time Picard connects to MB server.
  * [PICARD-1310] - Picard crashes on clearing log
  * [PICARD-1318] - RuntimeError: dictionary changed size during iteration
  * [PICARD-1321] - CD drive selection not working on Linux
  * [PICARD-1322] - Crash in options on "Restore defaults"
  * [PICARD-1323] - Restore defaults does not restore CAA types
  * [PICARD-1324] - Default locale not working reliable
  * [PICARD-1326] - Picard Save Changes 5.1 Mix Type
  * [PICARD-1327] - Loading TAK files fails
  * [PICARD-1328] - Loading OptimFROG files fails
  * [PICARD-1329] - Picard fails saving ID3 tags with iTunNORM tag
  * [PICARD-1331] - Picard crashes on error during plugin install
* Tue Aug 21 2018 alarrosa@suse.com
- Update to version 2.0.3
  * Bug-fix
  * [PICARD-1122] - Preffered release type settings are exclusive and should be inclusive
  * [PICARD-1207] - Move additional files feature fails when source directory contains non-ascii characters
  * [PICARD-1247] - Not all "preserved" tags are preserved
  * [PICARD-1305] - Search dialog crashes picard when record doesn't have an album
  * [PICARD-1306] - picard crashes when opening the options dialog if the cwd doesn't exist
  * New Feature
  * [PICARD-1289] - Allow manually running any tagger script
  * Improvement
  * [PICARD-1302] - Dropping an image from Google image crashes picard
  * [PICARD-1303] - picard crashes when matching a cluster with a release with no tracks
  * [PICARD-1304] - Info dialog for album crashes because track doesn't have a tracknumber
  * Regression
  * [PICARD-259] - Make file-specific variables available to tagger script
- Update to version 2.0.2
  * Bug-fix
  * [PICARD-1212] - Picard 2.0.0dev4 crashing at startup
  * [PICARD-1300] - Picard crashes when logging lots of events
- Update to version 2.0.1
  * No changes for linux users.
* Fri Jul 20 2018 aloisio@gmx.com
- Updated source URL
* Thu Jul 19 2018 aloisio@gmx.com
- Update to version 2.0
  Bug-fix
  * [PICARD-153] - Non-configuration data is saved in Picard.conf
  * [PICARD-173] - ID3 tag TSOP appears to be stored blank
  * [PICARD-340] - Cover art embedding will overwrite existing
    ones
  * [PICARD-405] - Save stopped working
  * [PICARD-817] - On high-resolution / high DPI displays,
    Picard's GUI is scaled wrong
  * [PICARD-1047] - Incompatible plugins are loaded with picard
    2.0
  * [PICARD-1051] - Searching for similar tracks causes coredumps
  * [PICARD-1052] - Not disabled Search for similar tracks can
    cause coredumps
  * [PICARD-1056] - Crash when viewing file info dialog
  * [PICARD-1058] - Saving images as files doesn't work
  * [PICARD-1062] - Picard crashes when moving files on release
  * [PICARD-1063] - After #689 unit tests fail if astrcmp is not
    compiled
  * [PICARD-1064] - python setup.py test -v doesn't work
  * [PICARD-1065] - python setup.py patch_version doesn't work
  * [PICARD-1066] - python setup.py update_constants doesn't work
  * [PICARD-1067] - Visual bug after un-checking an installed
    plugin
  * [PICARD-1073] - "Add New Tag" crashes picard
  * [PICARD-1084] - Picard 2 doesn't find DVD drive
  * [PICARD-1085] - Multi-Dir Add Folder not working
  * [PICARD-1105] - Crashes when using the edit tag dialog
  * [PICARD-1106] - cancel plugin installation file dialog
    results in crash
  * [PICARD-1114] - Cannot submit ratings in Picard 2.0 dev
  * [PICARD-1119] - picard sets "Disc Subtitle" to the track
    title
  * [PICARD-1123] - Multiple work languages are collapsed
  * [PICARD-1126] - Unhelpful error message logged on network
    request errors
  * [PICARD-1135] - Picard is not able to save on MTP devices
  * [PICARD-1138] - Search crashes due to AttributeError
  * [PICARD-1143] - Wrong amount of songs from added files
  * [PICARD-1147] - FYI, Can't load "Alan Parsons" album "On
    air" in Picard 1.2
  * [PICARD-1153] - "Lookup in Browser" and "Search" fail
    silently if artist name contains umlaut
  * [PICARD-1156] - Picard fails to start when trying to upgrade
    plugin which is a symlink
  * [PICARD-1159] - Can't open WAV files
  * [PICARD-1161] - Dragging artwork from Chrome pages doesn't
    work
  * [PICARD-1171] - Text of "About" can't be selected
  * [PICARD-1179] - Error while searching for alt. releases
  * [PICARD-1181] - In-app search dialog excessive slow down
  * [PICARD-1188] - Picard chooses incorrect value for language
    tag
  * [PICARD-1199] - Crash when right-clicking album
  * [PICARD-1202] - Right click on tag listing causes exception
    and crash
  * [PICARD-1203] - Hide unsupported tags from the tag diff in UI
  * [PICARD-1204] - Picard freezes on unchecking show diff tags
    first
  * [PICARD-1206] - Text is not displaying properly in some
    fields.
  * [PICARD-1210] - Long lines in the option dialogue don’t wrap
  * [PICARD-1213] - Wrong Movement of coverart providers
  * [PICARD-1215] - Does not use config / ini file specified on
    command line
  * [PICARD-1221] - Picard 2.0 won't start on Windows 10
  * [PICARD-1226] - Different fonts in the plugins dialog
  * [PICARD-1230] - Looking up CD crashes Picard
  * [PICARD-1234] - Crash when loading plugin from local
    directory
  * [PICARD-1252] - Crash on pasting invalid naming script
  * [PICARD-1253] - Crash on image saving
  * [PICARD-1255] - Crash on startup - no GUI
  * [PICARD-1265] - Can't "Lookup in Browser":
    UnicodeEncodeError: 'latin-1' codec can't encode characters in
    position 0-7: ordinal not in range(256)
  * [PICARD-1270] - Corruption of saved audio files located on a
    network share
  * [PICARD-1271] - Artist credit saved in tags sometimes loses
    closing parenthesis
  * [PICARD-1277] - Picard crashes on unknown cover art types
  New Feature
  * [PICARD-1187] - Add DSF file support
  * [PICARD-1220] - Add keyboard shortcut for deleting scripts
    from options > scripting page
  Task
  * [PICARD-960] - Migrate to PyQt5
  * [PICARD-1186] - Support only 64 bit Picard builds from 2.0
  Improvement
  * [PICARD-259] - Make file-specific variables available to
    tagger script
  * [PICARD-581] - Picard XML processing should use lxml module
    rather than QXmlStreamReader
  * [PICARD-588] - Picard 2.0 based on Python 3
  * [PICARD-807] - Retry release fetch on MB server overload
  * [PICARD-922] - Make multi-value script functions work
    correctly
  * [PICARD-976] - Reimplement the picard WS code to accommodate
    future versions of MBWS
  * [PICARD-978] - Distinguish in UI between unclustered and
    release unmatched files
  * [PICARD-1075] - Add unit tests for Metadata object variables
  * [PICARD-1087] - Improvements to UI for Lookup CD
  * [PICARD-1100] - Error when running confined in a snap
    because of gconf
  * [PICARD-1174] - Option to tolerate differences in track times
  * [PICARD-1200] - In Options dialog, tree pane on the left
    cannot be resized
  * [PICARD-1201] - Add a command-line option to not restore
    persisted UI sizes or positions
  * [PICARD-1211] - The “X” close button doesn’t work on the
    options dialogue
- Switched to python3 and Qt5
- Dropped SearchAmazon3.py,SearchAMG.py,SearchCastAlbums3.py,
  SearchDiscogs3.py,SearchFilmMusziek3.py,SearchGMR.py,
  SearchGoogle3.py,SearchLortelArchives3.py,
  SearchSoundtrackCollector3.py and SearchSoundtrackINFO3.py (not
  compatible with API v2.0)
- Spec cleanup
* Wed May 10 2017 alarrosa@suse.com
- Update to version 1.4.2:
  * Bugfix: Picard does not stop analyzer while moving (PICARD-1053)
  * Bugfix: Picard hangs with: RuntimeError: maximum recursion depth exceeded in cmp (PICARD-1055)
  * Bugfix: The "Convert Unicode punctuation characters to ASCII" function only works in certain tags (PICARD-1070)
  * Bugfix: ID3v2.4 text encoding settings are not saved correctly (PICARD-1077)
  * Improvement: Search dialog webservices get queued behind matched album requests (PICARD-969)
  * Improvement: Picard not seeing TOPE and TOAL (PICARD-1034)
* Sun May  7 2017 olaf@aepfle.de
- setup.py requires sip
* Fri Apr  7 2017 jengelh@inai.de
- Trim description as per the openSUSE description recommendations.
* Mon Apr  3 2017 alarrosa@suse.com
- Update to version 1.4.1:
  * Bugfix: Album shown matched even if extra unmatched files (PICARD-953)
  * Bugfix: Removing album with saves pending does not remove pending saves (PICARD-972)
  * Bugfix: Pending log messages not flushed to stderr on quit (PICARD-973)
  * Bugfix: Drag & Drop not working (PICARD-988)
  * Bugfix: Picard violating ID3 standard for TXXX frames (PICARD-990)
  * Bugfix: Disabling the cover art box and enabling it again doesn't bring it back (PICARD-996)
  * Bugfix: Disabling the action toolbar sometimes doesn't work (PICARD-998)
  * Bugfix: If a cluster is moved to the album side of the main window it gets moved to unmatched files (PICARD-1005)
  * Bugfix: Drag and drop for cover arts doesnt work on OSX (PICARD-1006)
  * Bugfix: Unsetting View/Cover Art doesn't work permanently (PICARD-1010)
  * Bugfix: Toolbar tab order incorrect after PICARD-908 (PICARD-1011)
  * Bugfix: Number of images in release info is calculated incorrectly (PICARD-1014)
  * Bugfix: Artwork tab of the Track Info DIalog doesn't show changes anymore (PICARD-1015)
  * Bugfix: CoverArtBox doesn't show new/removed images after unmatched files are added/removed to the album (PICARD-1018)
  * Bugfix: Directory persistence for Add Directory needs tweaking (PICARD-1023)
  * Bugfix: Fix ~artists_sort metadata variable (PICARD-1029)
  * Bugfix: Missing import for PICARD_APP_NAME (PICARD-1042)
  * New Feature: Visual feedback for changes to artwork in before-after pane. (PICARD-258)
  * New Feature: Implement artwork diff for albums (PICARD-1000)
  * Task: Remove monkey patching of file write methods in picard formats (PICARD-943)
  * Task: Replace Ok button text by Make It So! in Options dialog (PICARD-1041)
  * Improvement: Remove should work when Unmatched Files is selected (PICARD-223)
  * Improvement: Always use HTTPS for musicbrainz.org (PICARD-951)
  * Improvement: Use Cover Art Archive over HTTPS (PICARD-952)
  * Improvement: Mention AcoustID on Scan button too (PICARD-961)
  * Improvement: Drag&drop cover art doesn't work for images from amazon/google images/https links (PICARD-980)
  * Improvement: Buttons on the "User Interface" and "Scripting" pages are smaller than buttons in other places (PICARD-1012)
  * Improvement: Multiple images in related tracks confusing (PICARD-1016)
  * Improvement: Picard loads all pending files before quitting (PICARD-1021)
  * Improvement: Allow specifying a configuration file path (PICARD-1024)
  * Improvement: Allow to add/replace cover art images and keep existing cover art (PICARD-1030)
- Dropped 0001-Introduce-new-cover-art-thumbnail-class.patch,
  0002-Connect-events-for-CoverArtThumbnail-class.patch,
  0003-Update-coverartbox-class-to-include-new-and-original.patch,
  0004-Update-labels-in-_show-method.patch,
  0005-Update-mainwindow-to-display-original-coverart.patch,
  0006-Implement-__eq__-method-for-CoverArtThumbnail-and-up.patch,
  0007-Add-i18n-support-to-coverart-labels.patch,
  0008-Add-view-coverart-changes-button.patch,
  0009-Add-spacer-item-to-push-coverartbox-items-to-top.patch and
  fix-cover-art-downloads.diff which are already merged in 1.4.1
* Fri Feb 17 2017 olaf@aepfle.de
- Drop bonusdisc.py, URL disappeared
* Tue Feb 14 2017 alarrosa@suse.com
- Update to version 1.4.0
  * Bugfix: AcoustID submission fails with code 299 (PICARD-82)
  * Bugfix: Ignoring "hip hop rap" folksonomy tags also ignores "rap", "hip hop", etc. (PICARD-335)
  * Bugfix: Picard downloads multiple 'front' images instead of just first one. (PICARD-350)
  * Bugfix: Saving hidden file with only an extension drops the extension (PICARD-357)
  * Bugfix: Add directory opens in "wrong" dir (PICARD-366)
  * Bugfix: Picard should de-duplicate work lists (PICARD-375)
  * Bugfix: Tree selector in Options window is partially obscured, pane too narrow (PICARD-408)
  * Bugfix: tag acoustid_id can not be removed or deleted in script, renaming or plugin (PICARD-419)
  * Bugfix: Can't remove value from field (PICARD-546)
  * Bugfix: Can't open Options (PICARD-592)
  * Bugfix: "Tags from filenames" action stays enabled even if it is unavailable. (PICARD-688)
  * Bugfix: Using the first image type as filename changes the name of front images (PICARD-701)
  * Bugfix: Fingerprint Submission Failes if AcoustID tags are present and/or invalid (PICARD-706)
  * Bugfix: Picard moves into the selected folder (PICARD-726)
  * Bugfix: Picard does not support (recording) relationship credits (PICARD-730)
  * Bugfix: Picard repeats/duplicates field data (PICARD-748)
  * Bugfix: Number of pending web requests is not decremented on exceptions in the handler (PICARD-751)
  * Bugfix: Divide by zero error in _convert_folksonomy_tags_to_genre when no tag at the release/release group level (  PICARD-753)
  * Bugfix: Directory tree (file browser) not sorted for non-system drives under Windows (PICARD-754)
  * Bugfix: Crash when loading release with only zero count tags (PICARD-759)
  * Bugfix: No name and no window grouping in gnome-shell Alt-Tab app switcher (PICARD-761)
  * Bugfix: Lookup in Browser does not and can not load HTTPS version of musicbrainz.org (PICARD-764)
  * Bugfix: Unable to login using oauth via Picard options with Server Port set to 443 (PICARD-766)
  * Bugfix: "AttributeError: 'MetadataBox' object has no attribute 'resize_columns'" when enabling the cover art box (  PICARD-775)
  * Bugfix: Pre-gap tracks are not counted in absolutetracknumber (PICARD-778)
  * Bugfix: CAA cover art provider runs even if cover art has already been loaded (PICARD-780)
  * Bugfix: Toggling Embed Cover Art in Tags and restarting doesn't have the expected behavior (PICARD-782)
  * Bugfix: XMLWS redirects incorrectly (PICARD-788)
  * Bugfix: Handle empty collection-list in web server response (PICARD-798)
  * Bugfix: Amazon Cover Art provider does not work (and does not have a lot of debug logging enabled) (PICARD-799)
  * Bugfix: Cover Art from CAA release group is skipped even though it exists (PICARD-801)
  * Bugfix: Multiple instances of history and log dialogs (PICARD-804)
  * Bugfix: Empty string lookup (PICARD-805)
  * Bugfix: Will not load album information on any albums (PICARD-811)
  * Bugfix: Redirect URL is not encoded which leads to http 400 error. (PICARD-814)
  * Bugfix: Not compatible with latest Mutagen (PICARD-833)
  * Bugfix: Can't save any files.  Get: "error: invalid literal for int() with base 10" (PICARD-834)
  * Bugfix: Picard 1.3.2 shows cleartext username & password on status line when errors occur (PICARD-839)
  * Bugfix: Cannot fetch cover art from amazon link contains https scheme. (PICARD-848)
  * Bugfix: media-optical-modified.png icon still displayed after release save when two files match one track (PICARD-851)
  * Bugfix: Release that Picard will not load (due to disc with just data track?) (PICARD-853)
  * Bugfix: ValueError in metadata.py (PICARD-855)
  * Bugfix: Improper detection of Gnome as a desktop environment and no support for gnome 3 (PICARD-857)
  * Bugfix: Apparent non-functional tagger button (PICARD-858)
  * Bugfix: Picard does not read Ogg/Opus files with an ".ogg" file exension (PICARD-859)
  * Bugfix: Setting a large value in in $num function as length causes picard to become unresponsive (PICARD-865)
  * Bugfix: id3 deletion needs to be improved (PICARD-867)
  * Bugfix: id3v2.3 does not properly handle TMOO ( mood tag) (PICARD-868)
  * Bugfix: Coverart providers duplicates on reset (PICARD-870)
  * Bugfix: Restore defaults broken for plugins page and tagger scripts page (PICARD-873)
  * Bugfix: Coverart providers erroneous save (PICARD-874)
  * Bugfix: The metadatabox doesn't correctly show the tag selected  (PICARD-876)
  * Bugfix: Length tag for ID3 is no longer displayed in the metadata box (PICARD-881)
  * Bugfix: Removed tags are not removed from the metadatabox after saving the file (PICARD-882)
  * Bugfix: File Browser pane doesn't check for path type( file or folder) when setting home path/move files here (  PICARD-884)
  * Bugfix: mov files return a +ve score for mp4 container leading to errors (PICARD-885)
  * Bugfix: "Restore defaults" doesn't log out the user (PICARD-888)
  * Bugfix: Broken 'Restore Defaults' (PICARD-907)
  * Bugfix: Messagebox wraps and displays title inappropriately (PICARD-911)
  * Bugfix: An “empty” track shouldn’t get an “excellent match” tooltip. (PICARD-914)
  * Bugfix: In plugins list, some plugins don't show description (PICARD-915)
  * Bugfix: Plugin restore defaults broken (PICARD-916)
  * Bugfix: Does not use UI language but locale on Windows (PICARD-917)
  * Bugfix: Preserve scripting splitter position (PICARD-925)
  * Bugfix: Having trouble submitting AcoustIDs (PICARD-926)
  * Bugfix: Cluster double‐click opens the Info… panel (PICARD-931)
  * Bugfix: Status bar not cleared when selection changed (PICARD-937)
  * Bugfix: Open containing folder not working for shared files over network  (PICARD-942)
  * Bugfix: Warning: Plugin directory '…/python2.7/site-packages/contrib/plugins' doesn't exist (PICARD-945)
  * Bugfix: Additionnal files aren't moved anymore (PICARD-946)
  * Bugfix: Search window error message does not appear translated (PICARD-947)
  * Bugfix: Open Containing Folder duplicates (PICARD-950)
  * Bugfix: Errors when directory / file names contain unicode characters (PICARD-958)
  * New Feature: AIF support (ID3) (PICARD-42)
  * New Feature: Test and integrate support for "local" cover art into Picard (PICARD-137)
  * New Feature: Display infos (album, artist, tracklist) for clusters without release match (PICARD-680)
  * New Feature: Add download plugin functionality to existing UI (PICARD-691)
  * New Feature: Fallback on album artist's tags if no tags are found for album (PICARD-738)
  * New Feature: Add m2a as a supported extension (PICARD-743)
  * New Feature: MusicBrainz/AcoustID entities should be hyperlinked in Picard (PICARD-756)
  * New Feature: Support key tag (PICARD-769)
  * New Feature: Export / import settings (PICARD-901)
  * New Feature: Search releases from within a Picard dialog (PICARD-927)
  * New Feature: Searching tracks and displaying similar tracks in a dialog box (PICARD-928)
  * New Feature: Search for artists from dialog (PICARD-929)
  * Task: Picard default name files script refinement (PICARD-717)
  * Task: Update Picard logo/icons (PICARD-760)
  * Task: Link to the Scripting documentation on the Scripting options page (PICARD-779)
  * Task: Remove contrib/plugins from the repository (PICARD-835)
  * Task: Raise the required mutagen version to 1.22 (PICARD-841)
  * Task: Renaming save_only_front_images_to_tags option to something more appropriate  (PICARD-861)
  * Task: Allow translators to finalize translations before releasing Picard 1.4 (PICARD-895)
  * Task: Raise the required Python version to 2.7. (PICARD-904)
  * Task: Bump Picard’s copyright date (PICARD-912)
  * Task: Add Norwegian to UI languages (PICARD-982)
  * Task: Provide ~video variable for video tracks (PICARD-652)
  * Task: Improve error logging on AcoustId submission (PICARD-708)
  * Improvement: Link to Picard Scripting page under 'File Naming' (PICARD-22)
  * Improvement: Restore default settings button/s (PICARD-116)
  * Improvement: Speed of Ogg tag writing/updating (PICARD-133)
  * Improvement: Allow adding/removing tags to be preserved from context menu in the tag diff pane (PICARD-207)
  * Improvement: Make it easier to remove everything currently loaded in Picard (PICARD-210)
  * Improvement: Bring back keyboard shortcuts for editing tags (PICARD-222)
  * Improvement: Case sensitivity for "Move additional files" option (PICARD-229)
  * Improvement: Metadata comparison box shows that it intends to write (and has written) tags unsupported by   underlyingfile format (PICARD-253)
  * Improvement: Add more descriptive tooltips to buttons (PICARD-267)
  * Improvement: Allow musicip_puid and acoustid_id to be cleared from tags (PICARD-268)
  * Improvement: Make it possible to remove existing tags without clearing all tags (PICARD-287)
  * Improvement: Disable recurse subdirectories should be added (PICARD-291)
  * Improvement: display how many "pending files" left on lookup (PICARD-305)
  * Improvement: Handle MP3 TSST/TIT3 (subtitle) tags better with ID3v2.3 (PICARD-307)
  * Improvement: Customisable toolbars (PICARD-353)
  * Improvement: Ignore file extension and try to read anyway (PICARD-359)
  * Improvement: Make it possible to unset all performer (etc) tags (PICARD-384)
  * Improvement: Progress tracking (PICARD-388)
  * Improvement: Add ability to handle multiple tagger scripts (PICARD-404)
  * Improvement: the option "select all" to save (PICARD-476)
  * Improvement: Option to load only audio tracks, i.e. not DVD-Video, CD-ROM tracks (PICARD-514)
  * Improvement: Picard should use OAuth for authentication (PICARD-615)
  * Improvement: Improvements to WMA tags (PICARD-648)
  * Improvement: Only ask to "log in now" once per session (PICARD-678)
  * Improvement: Show codec info for MP4 files (PICARD-683)
  * Improvement: "Play File" button should be renamed to "Open in Player" (PICARD-692)
  * Improvement: ID3 padding not reduced can result in large files (PICARD-695)
  * Improvement: Set option 'caa_approved_only' disabled by default (PICARD-705)
  * Improvement: Validate fpcalc executable in options (PICARD-707)
  * Improvement: Improve File Naming options (PICARD-733)
  * Improvement: Add --long-version/-V option, outputting third parties libs versions as well as Picard version PICARD-734)
  * Improvement: missing info in the help file (PICARD-740)
  * Improvement: Pass command-line arguments to QtApplication (PICARD-773)
  * Improvement: Use the more detailed icons in more places on windows (PICARD-777)
  * Improvement: Use .ini configuration file on all platforms (PICARD-794)
  * Improvement: Use python2 shebang as of PEP 0394 (PICARD-806)
  * Improvement: Display existing covers in File Info dialog (PICARD-808)
  * Improvement: Use HTTPS for external links (PICARD-818)
  * Improvement: Install a scalable icon (PICARD-838)
  * Improvement: Use HTTPS for requests to the plugins API on picard.musicbrainz.org (PICARD-852)
  * Improvement: Use magic numbers to determine the audio file types instead of relying on extensions (PICARD-864)
  * Improvement: Multi-scripting UI is very basic (PICARD-883)
  * Improvement: Allow scripting functions to have arbitrary number of arguments (PICARD-887)
  * Improvement: The "Restore defaults" confirmation buttons should follow the quit confirmation dialog in style PICARD-890)
  * Improvement: Replace submit icon with AcoustID logo (PICARD-896)
  * Improvement: Rename "Submit" button to "Submit AcoustIDs" (PICARD-897)
  * Improvement: Use UTF-8 for ID3v2.4 by default instead of UTF-16 (PICARD-898)
  * Improvement: Restore defaults is slightly broken for tags option page (PICARD-902)
  * Improvement: Rearrange the action toolbar icons from left to right according to the expected user-flow (PICARD-908)
  * Improvement: Add tooltips to “Restore all Defaults” and “Restore Defaults” (PICARD-913)
  * Improvement: Make PICARD-883 UI have adjustable widths for list of scripts and script content (PICARD-918)
  * Improvement: Move Options/Advanced/Scripting to Options/Scripting (PICARD-919)
  * Improvement: Move UI options page up the options tree (PICARD-921)
  * Improvement: Add $startswith and $endswith string functions (PICARD-923)
  * Improvement: Make list of scripts smaller than script text by default (PICARD-924)
  * Improvement: Wait for save thread pool to be finished before exit  (PICARD-944)
  * Improvement: New guess format functionality should use explicit buffer size (PICARD-970)
* Tue Feb 14 2017 alarrosa@suse.com
- Fix the source urls for the plugins.
* Sun Feb 12 2017 alarrosa@suse.com
- Add 0001-Introduce-new-cover-art-thumbnail-class.patch
  0002-Connect-events-for-CoverArtThumbnail-class.patch
  0003-Update-coverartbox-class-to-include-new-and-original.patch
  0004-Update-labels-in-_show-method.patch
  0005-Update-mainwindow-to-display-original-coverart.patch
  0006-Implement-__eq__-method-for-CoverArtThumbnail-and-up.patch
  0007-Add-i18n-support-to-coverart-labels.patch
  0008-Add-view-coverart-changes-button.patch
  0009-Add-spacer-item-to-push-coverartbox-items-to-top.patch
  which are part of pull request 586, which fixes PICARD-258.
  This pull request was already approved upstream but will be merged
  after 1.4.0 is released.
- This makes picard show visual feedback in the main window
  for coverart changes in tracks.
* Sat Feb 11 2017 alarrosa@suse.com
- Add fix-cover-art-downloads.diff, which fixes drag&drop issues with
  cover art images from amazon/google images/urls using https.
* Wed Jun 29 2016 hpj@urpla.net
- add recommends for python-discid
* Wed Feb 24 2016 olaf@aepfle.de
- Remove sco locale to fix build in SLE_11
* Tue Dec  8 2015 olaf@aepfle.de
- Remove ffmpeg from BuildRequires, it is not used anymore
- Recommend chromaprint-fpcalc
* Sat Apr  4 2015 avvissu@yandex.ru
- Fix build in PMBS: use libffmpeg-devel instead of ffmpeg-devel
* Wed Mar 11 2015 p.drouand@gmail.com
- Update to version 1.3.2
  * Bugfix: Fixed tags from filename dialog not opening on new installations
- Remove some useless stuff
* Tue May 21 2013 ohering@suse.de
- Update to version 1.2 - 2013-03-30
  - Picard now requires at least Python 2.6
  - Removed support for AmpliFIND/PUIDs
  - Add support for the Ogg Opus file format
  - It's now possible to download cover images without any plugin.
    Cover Art Archive images can be downloaded by image type
  - Improved directory scanning performance
  - Prefer already-loaded releases of the same RG when matching files
  - Allow dropping new files onto specific targets
  - Add basic collections management support (PICARD-84)
  - Allow adding custom tags in the tag editing dialog (PICARD-349)
  - Fix replacing of Windows-incompatible characters (PICARD-393)
  - Save both primary and secondary release types (PICARD-240)
  - Handle errors from the AcoustID service better (PICARD-391)
  - Accept HTTPS URLs on drag-and-drop (PICARD-378)
  - Allow adding custom tags in the tag editor (PICARD-349)
* Wed Nov 14 2012 ohering@suse.de
- install contrib/plugins/coverart.py
* Mon Oct 15 2012 ohering@suse.de
- Update to version 1.1 - 2012-09-03
  - Always show basic tags in metadata comparison box, even if empty (title,
    artist, album, tracknumber, ~length, date) (PICARD-201)
  - Fixed AcoustID submission failure after removing files from Picard (PICARD-82)
  - Allow multi-select in new MetaDataBox for delete/remove tags (PICARD-194)
  - File browser remembers last directory/no longer crashes on OS X (PICARD-104)
  - Refreshing a non-album track correctly clears previous track metadata (PICARD-220)
  - Fixed the preserved tags setting for tags with uppercase characters (PICARD-217)
  - Added a completion box to the preserved tags setting, and clarified how it works
  - Store lyrics language in tags instead of text representation language (PICARD-242)
  - Fix various oddities in the metadata comparison box (PICARD-255, PICARD-256)
* Sun Jun 10 2012 ohering@suse.de
- Update to version 1.0 - 2012-06-02
  - New UI: Extended comparison of existing vs. MB metadata & tags (PICARD-43)
  - Merged the renaming and moving options pages
  - Removed the VA file naming format option (there is now a single format option) (PICARD-159)
  - Add %%license%% tag
  - Made %%writer%% available to tagger scripts and plugins with contents of songwriter (PICARD-21)
  - Allow two multi-valued variables to be merged in tagger scripting (PICARD-139)
  - Allow multi-valued variables to be transformed in tagger script and then set back in tags as multi-valued (PICARD-147)
  - Fix $copy not preserving multi-value variables as documented (PICARD-138)
  - Load/save free-text tags for ID3 as TXXX frames (PICARD-148)
  - Fix writing of MusicBrainz Work Id / musicbrainz_workid to tags (PICARD-88)
  - Handle mimetype for embedding cover art from EXIF jpegs (PICARD-27)
  - Change cover art box to open MusicBrainz release rather than Amazon
  - Support manual drag-and-drop of cover art onto a release via cover art box
  - Only open browser on left-click of cover art box (PICARD-190)
  - Fix Lookup in Browser (previously 'tag lookup') for clusters (PICARD-186)
  - Lookup in Browser will now not use MBIDs to lookup unmatched files/clusters
  - Add Date/Country to CD Lookup results dialog (PICARD-198)
  - Fix/reset album folksonomy tag counts while refreshing releases (PICARD-4)
  - Plugins actions can now create sub-menus using the MENU class attribute
  - New plugin hook register_clusterlist_action
  - Display the port Picard is listening on at bottom right status bar (PICARD-191)
  - Make album drops from right hand pane to left default to "unmatched files" again (PICARD-33)
  - Remove .DS_Store, desktop.ini, and Thumbs.db from otherwise empty directories (PICARD-75)
  - Update artist translation to use new alias features (primary flag, sort names) (PICARD-200)
  - Deleted tags aren't indicated as changes (PICARD-165)
  - Picard log entries have inaccurate timestamp (PICARD-45)
  - Interface doesn't allow keyboard only management (PICARD-103)
  - Added option to preserve timestamps of tagged files (PICARD-31)
  - Added keyboard shortcut to reload release (PICARD-99)
  - Medium formats weren't listed in order in the "Other versions" menu (PICARD-91)
  - Couldn't select multiple directories in "Add Folder" window on OS X (PICARD-74)
* Wed Apr 11 2012 saschpe@suse.de
- Remove obsolete SUSE version checks
- Call icon_theme_cache_post(un) (bnc#756522)
- Remove Mandriva checks, not tested nor enabled in this project
* Sun Apr  1 2012 ohering@suse.de
- Update to version 0.16 - 2011-10-23
  - Added AcoustID support.
  - Fixed track metadata plugins.
  - Added new internal %%_totalalbumtracks%% tag field. (PICARD-16)
  - Track metadata plugins now run also on non-album tracks. (PICARD-7)
  - Fixed custom Various Artists name on the %%albumartist%% field. (PICARD-5)
  - Album artist is now correctly "translated". (PICARD-1)
  - Unicode punctuation is now converted to ASCII by default.
  - WavPack correction files are moved together with the main files. (PICARD-15)
  - Unicode filename normalization on OS X.
  - Original release date is now saved into %%originaldate%%.
  - Allow tagging with localized artist aliases (PICARD-17)
  - Added a quit confirmation dialog. (PICARD-46)
  - Standalone recordings can be tagged with relationships now. (PICARD-10)
  - Refreshing an album will refresh its "other versions" listing. (PICARD-8)
  - "Unicode punctuation to ASCII" now works on album-level metadata. (PICARD-50)
  - DJ-mix tags should only be written to the medium where they apply. (PICARD-20)
  - Support URL redirects in web service/network request module (PICARD-54)
  - Jamendo and Archive.org cover art is displayed on web page, but not loaded by Picard plugin (PICARD-52)
  - Edits to metadata in "Details..." menu not reflected in UI (PICARD-13)
  - The status bar/new metadata box is updated when a selected file/track is changed. (PICARD-14)
* Thu Feb 23 2012 Ralf Lang <lang@b1-systems.de>
- add a requires: on python-qt4. picard will not run without this
* Tue Feb 21 2012 saschpe@suse.de
- Ran spec-cleaner
* Mon Feb 20 2012 pascal.bleser@opensuse.org
- add conditional BUILD_ORIG_ADDON to buildrequire ffmpeg-devel and enable
  ffmpeg fingerprinting support when picard is linked and built on Packman
* Mon Aug  1 2011 ohering@suse.de
- Update to version 0.15.1 - 2011-07-31
  - "Other versions" menu now displays release labels and catalog numbers.
  - Added CD-R, 8cm CD to the format mapping.
  - Picard no longer fails to load releases with new or unknown media formats.
  - Threading issues that could occasionally cause Picard to stop loading files have been fixed.
  - Fixed album metadata processor plugins not working (#5960)
  - Fixed loading of standalone recordings (#5961)
  - Fixed requests stopping at midnight (#5963)
  - Stopped using QDateTime for timing requests (for Qt 4.6 compatibility) (#5967)
  - Fixed display of ampersands in the "other versions" menu. (#5969)
  - Fixed use of numerical functions in advanced scripting.
* Mon Jul 25 2011 ohering@suse.de
- Update name of dlopen libdiscid object during build
* Mon Jul 25 2011 ohering@suse.de
- Update additional python plugins to report compatibility for 0.15
* Mon Jul 25 2011 ohering@suse.de
- Run dos2unix on additional python plugins
* Mon Jul 25 2011 ohering@suse.de
- Update to version 0.15 - 2011-07-17
  - Added options for using standardized track, release, and artist metadata.
  - Added preferred release format support.
  - Expanded preferred release country support to allow multiple countries.
  - Added support for tagging non-album tracks (standalone recordings).
  - Plugins can now be installed via drag and drop, or a file browser.
  - Added several new tags: %%%%_originaldate%%%%, %%%%_recordingcomment%%%%, and %%%%_releasecomment%%%%
  - Changes to request queuing: added separate high and low priority queues for each host.
  - Tagger scripts now run after metadata plugins finish (#5850)
  - The "compilation" tag can now be $unset or modified via tagger script.
  - Added a shortcut (Ctrl+I) for Edit->Details.
  - Miscellaneous bug fixes.
  - Support for the NGS web service
  Version 0.14 - 2011-05-15
  - Fixed a problem with network operations hanging after a network error (#5794, #5884)
  - ID3v2.3 with UTF-16 is now the default ID3 version
  - Option to set preferred release types for improved album matching
  - Added support for sorting the album/file lists (#75)
  - Fixed OptimFROG tag reading (#5859)
  - Fixed colors for a white-on-black color scheme (#5846)
  - Added an option to replace non-ASCII punctuation (#5834)
  - Support for writing release group and work IDs, currently unused (#5805)
  - Fixed saving of the release event format tag (#5250)
  - Added support for the language and script tags (#943)
  - Plugins can now use track-track relationships (#5849)
  - Allowed external drives to be visible in the file browser panel on OS X (#5308)
  Version 0.13 - 2011-03-06
  - Changed Picard icon license to CC by-sa
  - Small UI consistency changes
  - Albums with tracks linked to more than one file are never marked as
    "completed".
  - Fixed matching of scanned files to tracks while the album is still loading.
  - Support for properly embedded FLAC pictures
  - Existing embedded images in APE and ASF files are removed only if there
    are new images to replace them.
  - More strict tagger script validation.
  - Fixed the $truncate tagger script function.
  - Proper rounding of track durations.
  - Fixed a bug with saving images larger than 64k to WMA files.
  - Added a $swapprefix tagger script function.
  - Release events with a date are preferred over the ones without a date.
  - Files that are being saved as marked as pending.
  - Updated .desktop file to allow opening Picard with multiple files.
  - Handle the "open file" event on Mac OS X.
  - Added timeouts to the HTTP web service client.
  - Fixed a bug with albums missing the expand/collapse icons
* Mon Jul 25 2011 ohering@suse.de
- Include a dummy binary to add the correct rpm dependency to the
  libdiscid SONAME in the package. The python code uses dlopen.
* Mon Jul 25 2011 ohering@suse.de
- Update specfile to include URLs to plugins
* Mon Jul 25 2011 ohering@suse.de
- Remove incorrect sles_version check for libdiscid-devel
  The package will be required unconditionally to read Audio CDs
* Wed Feb  2 2011 saschpe@suse.de
- Don't install unsupported locale 'sco' on openSUSE > 11.3
- Fixed icons directory ownership and added hicolor-icon-theme
  dependency
* Wed Aug 25 2010 sasch.pe@gmx.de
- Updated to upstream version 0.12.1+bzr1043
- Icon license now complies with openSUSE packaging guidelines
* Mon Apr 19 2010 sasch.pe@gmx.de
- Added several plugins
* Tue Jan  5 2010 masterpatricko@gmail.com
- Updated to upstream v0.12.1
* Fri Jan 23 2009 masterpatricko@gmail.com
- Updated to upstream v0.11
* Mon Jun 30 2008 jfunk@funktronics.ca
- Adapt to non-standard python build
* Fri Feb  1 2008 jfunk@funktronics.ca
- Update to final v0.9
* Mon Sep  3 2007 jfunk@funktronics.ca
- Initial release
